
#include <ctime>
#include <vector>
#include <iostream>
#include <algorithm>
using namespace std;

const int MAXR = 505, MAXC = 505, MAXN = 1005;

int R, C;
int m[MAXR];
bool mark[MAXR];
bool can[MAXC][MAXR];
int latin[MAXR][MAXC];

int S, T, N;
int d[MAXN], q[MAXN];
char edge[MAXN][MAXN];

void build() {
    S = C + C;
    T = C + C + 1;
    N = C + C + 2;
    
    memset(can, true, sizeof(can));
    for (int i = 0; i < R; ++i)
        for (int j = 0; j < C; ++j)
            can[j][latin[i][j] - 1] = false;
    
    for (int i = 0; i < C; ++i) {
        for (int j = 0; j < C; ++j)
            if (can[i][j])
                edge[i][C + j] = 1;
    }
}

bool dfs(int at) {
    if (at == T)
        return true;
    for (int i = 0; i < N; ++i)
        if (edge[at][i] && d[at] - 1 == d[i]) {
            if (dfs(i)) {
                edge[at][i] = 0;
                edge[i][at] = 1;
                return true;
            } else {
                d[i] = -1;
            }
        }
    return false;
}

int flow() {
    int res = 0;
    while (true) {
        int qh = 0;
        int qt = 1;
        q[qh] =  T;
        memset(d, -1, sizeof(int) * N);
        d[T] = 0;
        while (qh < qt) {
            int at = q[qh];
            ++qh;
            for (int j = 0; j < N; ++j)
                if (edge[j][at] && d[j] == -1) {
                    d[j] = d[at] + 1;
                    q[qt] = j;
                    ++qt;
                }
        }
        if (d[S] < 0)
            break;
        while (dfs(S)) {
            ++res;
        }
    }
    return res;
}

void solve() {
    for (int i = 0; i < C; ++i) {
        edge[S][i] = 1;
        edge[i][S] = 0;
        edge[C + i][T] = 1;
        edge[T][C + i] = 0;
    }
    assert(flow() == C);
    
    for (int i = 0; i < C; ++i)
        for (int j = 0; j < C; ++j)
            if (edge[C + j][i]) {
                latin[R][i] = j + 1;
                can[i][j] = false;
                edge[C + j][i] = 0;
            }
}

void check() {
    vector <int> a(C);
    for (int i = 0; i < R; ++i) {
        for (int j = 0; j < C; ++j)
            a[j] = latin[i][j];
        sort(a.begin(), a.end());
        for (int j = 1; j <= C; ++j)
            assert(a[j - 1] == j);
    }
    for (int j = 0; j < C; ++j) {
        for (int i = 0; i < C; ++i)
            a[i] = latin[i][j];
        sort(a.begin(), a.end());
        for (int i = 1; i <= C; ++i)
            assert(a[i - 1] == i);
    }
}

bool good() {
    static int perm[MAXN];
    for (int i = 0; i < C; ++i)
        perm[i] = i;
    for (int i = 0; i < 100; ++i) {
        random_shuffle(perm, perm + C);
        bool ok = true;
        for (int j = 0; j < C; ++j)
            if (!can[j][perm[j]]) {
                ok = false;
                break;
            }
        if (ok) {
            for (int j = 0; j < C; ++j) {
                can[j][perm[j]] = false;
                latin[R][j] = perm[j] + 1;
            }
            ++R;
            cout << "COOL!" << endl;
            return true;
        }
    }
    return false;
}

void stupid() {
    memset(can, true, sizeof(can));
    for (int i = 0; i < R; ++i)
        for (int j = 0; j < C; ++j)
            can[j][latin[i][j] - 1] = false;
    while (R < C) {
        if (!good())
            break;
    }
}

int main() {
//    clock_t start = clock();
    scanf("%d %d", &R, &C);
    for (int i = 0; i < R; ++i)
        for (int j = 0; j < C; ++j)
            scanf("%d", &latin[i][j]);
//    stupid();
    build();
    while (R < C) {
        solve();
        ++R;
    }
    printf("%d\n", R);
    for (int i = 0; i < R; ++i, puts(""))
        for (int j = 0; j < C; ++j) {
            if (j > 0)
                printf(" ");
            printf("%d", latin[i][j]);
        }
//    clock_t end = clock();
//    fprintf(stderr, "%lf\n", (0.0 + end - start) / CLOCKS_PER_SEC);
//    check();
    return 0;
}
