
#include <cmath>
#include <iostream>
using namespace std;

const double EPS = 1e-9;

inline double angle(double x, double y) {
    double a = (atan2(y, x) * 180.0) / M_PI;
    if (a < 0.0)
        a += 360.0;
    return a / 360.0;
}

#define debug(x) cout << #x << ": " << x << endl;

struct four {int x, y, v, d;};
four A, B;

double get_pos(double t, double x, double y, int v, int d) {
    double a = angle(x, y); 
    double cir_len = sqrt(x * x + y * y) * M_PI * 2.0; 
    double S = v * t; 
    S = S - ((long long) (S / cir_len)) * cir_len;
    S /= cir_len; 
    if (d == 1)
        a -= S;
    else
        a += S;
    if (a < 0.0)
        a += 1.0;
    if (a >= 1.0)
        a -= 1.0;
    return a;
}
double get_pos(double t, four z) {
    return get_pos(t, z.x, z.y, z.v, z.d);
}


double dist(double t) {        
    double p = get_pos(t, 0.0 + A.x, 0.0 + A.y, A.v, A.d);
    double q = get_pos(t, 0.0 + B.x, 0.0 + B.y, B.v, B.d);
    return min(1 - fabs(p - q), fabs(p - q));
}

double find_zero(double off) {
    double R = EPS;
    
    while (true) {
        double l = 0.0;
        double r = R; R *= 2.0;
        while (r - l > EPS) {
            double m1 = (l + l + r) / 3;
            double m2 = (l + r + r) / 3;
            if (dist(off + m1) < dist(off + m2))
                r = m2;
            else
                l = m1;
//            cout << l << " " << r << endl;
        }
        if (dist(off + l) < 1e-6) {
//            cout << off + l << " " << "FIRST_ONE_MAYBE" << endl;
            return off + l;
//            break;
//            return off + l;
        }
    }
}

int main() {
    cin >> A.x >> A.y >> A.v >> A.d;
    cin >> B.x >> B.y >> B.v >> B.d;
    
    int K;
    cin >> K;
    
    double X = find_zero(0.0);
    double Y = find_zero(X + 1e-4);
    double P = (Y - X) * (0.0 + K - 1);
    double res = X + P;
    char str[100];
    sprintf(str, "%.20lf", res);
    int pos = 0;
    while (str[pos] != '.')
        putchar(str[pos++]);
    puts("");
    
    // CHECK IF THEY ARE IN THE SAME POSITION INITIALLY!
//    printf("%.20lf %.20lf\n", l, r);
//    printf("%.20lf %.20lf\n", get_pos(l, A), get_pos(l, B));
    return 0;
    /*
    for (double t = 0.0; t <= 35.0; t += 0.1) {
        double p = get_pos(t, x1, y1, v1, d1);
        double q = get_pos(t, x2, y2, v2, d2);
        cout << t << " " << p << " " << q << " " << min(1 - fabs(p - q), fabs(p - q)) << endl;
        cout << endl;
 
    }*/   
    return 0;
}
